@@ -1,9 +1,9 @@
-class.edge.all <-
-function(tree,subtree,subroot="drop"){
+class.edge.all <- function(tree,subtree,subroot="drop"){
 	# subtree is the index of the subtree
 	# identify edges not in the subtree
-	tree$edge.length <- as.numeric(make.unique(as.character(tree$edge.length),""))
-	subtree <- subtrees(tree)[[subtree]]
+	L<-length(tree$edge.length)
+	tree$edge.length<-1:L
+	subtree <- subtreez(tree, From=subtree, To=subtree)[[1]]
 	labs <- is.na(match(tree$edge.length, subtree$edge.length))
 	# identify edges with no descendant nodes in the subtree
 	ls <- is.na(match(tree$edge.length,subtree$edge.length))*is.na(match(tree$edge[,2],subtree$node.label))
@@ -12,4 +12,3 @@ function(tree,subtree,subroot="drop"){
 	if(subroot=="drop"){labs[labs>ls] <- NA}
 	labs
 	}
-
