@@ -30,7 +30,7 @@ subtreez <- function(tree, From, To, wait = FALSE)
             len.tip <- res[res < N.tip + 1]
             vec <- 1:length(tree$tip.label)
             len.tip.stay <- setdiff(vec, len.tip)
-            tree2 <- drop.tip(tree, len.tip.stay)
+            tree2 <- drop.tip2.6(tree, len.tip.stay)
        # }
         sub[[u]] <- tree2
         sub[[u]]$name <- k
